<?php
/**
 * @package WordPress
 * @subpackage MagUp_Theme
 */
if ( ! isset( $content_width ) ) $content_width = 640;
//Check for Post Thumbnail Support

add_theme_support( 'post-thumbnails' );
add_theme_support( 'automatic-feed-links' );


function magup_init_method() {
	if ( is_singular() ) wp_enqueue_script( 'comment-reply' );
    wp_register_script( 'jquery.innerfade', get_template_directory_uri()."/scripts/jquery.innerfade.js");
    wp_register_script( 'jquery.bottom-slider', get_template_directory_uri()."/scripts/jquery.bottom-slider.js");
    wp_register_script( 'jquery.li-scroller', get_template_directory_uri()."/scripts/jquery.li-scroller.1.0.js");
    wp_register_script( 'jquery.prettyPhoto', get_template_directory_uri()."/scripts/jquery.prettyPhoto.js");
    wp_register_script( 'magup_custom_script', get_template_directory_uri()."/scripts/custom.js");
    wp_enqueue_script("jquery");
    wp_enqueue_script( 'jquery.innerfade' );
    wp_enqueue_script( 'jquery.bottom-slider' );
    wp_enqueue_script( 'jquery.li-scroller' );
    wp_enqueue_script( 'jquery.prettyPhoto' );
    wp_enqueue_script( 'magup_custom_script' );
	register_nav_menu( 'magup_main_menu', 'The main menu on top' );

}    
 
add_action('init', 'magup_init_method');
add_action("widgets_init", "magup_widget_init");

load_theme_textdomain( 'magup', TEMPLATEPATH . '/lang' );
//add_editor_style();

//Function to get Thumbnail URL
function magup_get_thumbnail_src($_dim=array(71,71)) {
	global $post;
	if (function_exists('has_post_thumbnail')) {
			// get featured image
		$post_thumbnail_id = get_post_thumbnail_id(  );                      
		$image_src = get_the_post_thumbnail( $post->ID,$_dim); 
			
		if (empty($image_src)){ // get first featured gallery image 
			$attachments = get_children( array('post_parent' => $post->ID, 'post_type' => 'attachment', 'post_mime_type' => 'image') );
			foreach ( $attachments as $attachment_id => $attachment ) {
				$attAr[] = wp_get_attachment_image($attachment_id,$_dim);
			}
			if (isset($attAr) && is_array($attAr))
				$image_src = $attAr[0];
		}
		return $image_src;
	} elseif(get_post_meta($post->ID, 'featured', TRUE)) {
		$img = get_post_meta($post->ID, 'featured', TRUE);
		return $img;
	} else {
    
	}
}
//Limit the Content
function magup_excerpt($limit) {
	$excerpt = explode(' ', get_the_excerpt(), $limit);
  	if (count($excerpt)>=$limit) {
    	array_pop($excerpt);
    	$excerpt = implode(" ",$excerpt).'...';
	} else {
    	$excerpt = implode(" ",$excerpt);
  	}	
  	$excerpt = preg_replace('`\[[^\]]*\]`','',$excerpt);
  	return magup_excerpt_more($excerpt);
}
function magup_have_excerpt($limit) {
	$excerpt = explode(' ', get_the_excerpt(), $limit);
  	if (count($excerpt)>=$limit) {
		return true;
	} else {
    	return false;
  	}	
}
//Make new excerpt Link
function magup_excerpt_more($text){  
	global $post;
	return str_replace('...', ' <a class="more" href="'. get_permalink($post->ID) . '">' . '[more&hellip;]' . '</a>', $text);  
}
add_filter('the_excerpt','magup_excerpt_more');

function magup_widget_init(){
		register_sidebar(array(
			'name'=>'Sidebar right',
			'before_widget' => '<li id="%1$s" class="widget %2$s">',
			'after_widget' => '</li>',
			'before_title' => '<h2 class="widgettitle">',
			'after_title' => '</h2>',
		));
		register_sidebar(array(
			'name'=>'Footerbar'
		));
		register_sidebar(array(
			'name'=>'Home-Category-Teaser'
		));
}


//Loading Theme Options Framework

function magup_get_default_options() {
     $options = array(
          'slide_cat' => 1,
          'slide_posts' => 10,
          'feat_cat' => 1,
          'feat_posts' => 10,
          'feat_cats' => 1,
          'sidebar_banner_1' => '',
          'sidebar_banner_2' => '',
          'content_banner' => ''
     );
     return $options;
}
function magup_options_init() {
     // set options equal to defaults
     global $magup_options;
     $magup_options = get_option( 'theme_magup_options' );
     if ( false === $magup_options ) {
          $magup_options = magup_get_default_options();
     }
     update_option( 'theme_magup_options', $magup_options );
}
// Initialize Theme options
add_action('after_setup_theme','magup_options_init', 9 );

function magup_get_settings_page_tabs() {
     $tabs = array(
          'general' => 'General',
     );
     return $tabs;
}

function magup_admin_options_page_tabs( $current = 'general' ) {
     if ( isset ( $_GET['tab'] ) ) :
          $current = $_GET['tab'];
     else:
          $current = 'general';
     endif;
     $tabs = magup_get_settings_page_tabs();
     $links = array();
     foreach( $tabs as $tab => $name ) :
          if ( $tab == $current ) :
               $links[] = '<a class="nav-tab nav-tab-active" href="?page=magup-settings&tab='.$tab.'">'.$name.'</a>';
          else :
               $links[] = '<a class="nav-tab" href="?page=magup-settings&tab='.$tab.'">'.$name.'</a>';
          endif;
     endforeach;
     echo '<div id="icon-themes" class="icon32"><br /></div>';
     echo '<h2 class="nav-tab-wrapper">';
     foreach ( $links as $link )
          echo $link;
     echo '</h2>';
}

// Add "Magup Options" link to the "Appearance" menu
function magup_menu_options() {
	global $magup_adminhelp_hook;
    $magup_adminhelp_hook = add_theme_page('Theme Options', 'Theme Options', 'edit_theme_options', 'magup-settings', 'magup_admin_options_page');
}

function magup_adminhelp($contextual_help, $screen_id, $screen) {

	global $magup_adminhelp_hook;
	if ($screen_id == $magup_adminhelp_hook) {

		$contextual_help = 'To find a category ID go to /wp-admin/categories.php and click on one of the category names. The url of the page you are on will show what the category id is. eg wp-admin/categories.php?action=edit&cat_ID=11 means the category is 11.';
	}
	return $contextual_help;
}

add_filter('contextual_help', 'magup_adminhelp', 10, 3);


// Load the Admin Options page
add_action('admin_menu', 'magup_menu_options');

// Admin settings page markup
function magup_admin_options_page() { ?>
     <div class="wrap">
          <?php magup_admin_options_page_tabs(); ?>
          <?php if ( isset( $_GET['settings-updated'] ) ) {
               echo "<div class='updated'><p>Theme settings updated successfully.</p></div>";
          } ?>
     <form action="options.php" method="post">
     <?php
     settings_fields('theme_magup_options');
     do_settings_sections('magup');
     ?>
     <?php $tab = ( isset( $_GET['tab'] ) ? $_GET['tab'] : 'general' ); ?>
     <input name="theme_magup_options[submit-<?php echo $tab; ?>]" type="submit" class="button-primary" value="<?php esc_attr_e('Save Settings', 'magup'); ?>" />
     <!--<input name="theme_magup_options[reset-<?php echo $tab; ?>]" type="submit" class="button-secondary" value="<?php esc_attr_e('Reset Defaults', 'magup'); ?>" />-->
     </form>
     </div>
<?php }


function magup_adminoptions_init(){
	register_setting( 'theme_magup_options', 'theme_magup_options', 'magup_options_validate' );
	// Add a form section for the Header settings
	add_settings_section('magup_settings_general_homepage', 'Homepage Options', 'magup_settings_general_homepage_section_text', 'magup');
	add_settings_field('magup_setting_slide_cat', 'Slider Category ID', 'magup_setting_slide_cat', 'magup', 'magup_settings_general_homepage');
	add_settings_field('magup_setting_slide_posts', 'Slideshow Posts Numbers', 'magup_setting_slide_posts', 'magup', 'magup_settings_general_homepage');
	add_settings_field('magup_setting_feat_cat', 'Featured Articles Category ID', 'magup_setting_feat_cat', 'magup', 'magup_settings_general_homepage');
	add_settings_field('magup_setting_feat_posts', 'Featured Articles Number', 'magup_setting_feat_posts', 'magup', 'magup_settings_general_homepage');
	add_settings_field('magup_setting_feat_cats', 'Featured Categories Category ID', 'magup_setting_feat_cats', 'magup', 'magup_settings_general_homepage');
	add_settings_section('magup_settings_advertising_homepage', 'Homepage Advertising Options', 'magup_settings_advertising_homepage_text', 'magup');
	add_settings_field('magup_setting_sidebar_banner_1', 'Sidebar 1 160x600px', 'magup_setting_sidebar_banner_1', 'magup', 'magup_settings_advertising_homepage');
	add_settings_field('magup_setting_sidebar_banner_2', 'Sidebar 2 160x600px', 'magup_setting_sidebar_banner_2', 'magup', 'magup_settings_advertising_homepage');
	add_settings_field('magup_setting_content_banner', 'Content Banner 468x60px', 'magup_setting_content_banner', 'magup', 'magup_settings_advertising_homepage');


}

add_action('admin_init', 'magup_adminoptions_init' );

// Homepage Settings Section
function magup_settings_general_homepage_section_text() { ?>
     <p><?php _e( 'Here you can set the options for the homepage.', 'magup' ); ?></p>
	<?php 
}
// Homepage Settings Section
function magup_settings_advertising_homepage_text() { ?>
     <p><?php _e( 'Here you can set the 3 Banners for the homepage.', 'magup' ); ?></p>
	<?php 
}


// Slider Category ID
function magup_setting_slide_cat() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<input id='magup_setting_slide_cat' name='theme_magup_options[slide_cat]' size='40' type='text' value='<?php echo "{$magup_options['slide_cat']}" ?>' />
	<span class="description"><?php _e('This is the category that will be shown in the Slideshow on the frontpage, use comma to seperate multiple IDs.','magup'); ?></span>
	<?php 
}
// Slider Category Posts
function magup_setting_slide_posts() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<input id='magup_setting_slide_posts' name='theme_magup_options[slide_posts]' size='40' type='text' value='<?php echo "{$magup_options['slide_posts']}" ?>' />
	<span class="description"><?php _e('Select the number of posts you want to show in the Slideshow, leave empty if you want to show all.','magup'); ?></span>
	<?php 
}


// Featured Articles Category ID
function magup_setting_feat_cat() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<input id='magup_setting_feat_cat' name='theme_magup_options[feat_cat]' size='40' type='text' value='<?php echo "{$magup_options['feat_cat']}" ?>' />
	<span class="description"><?php _e('This sets the category ID for featured Articles on Homepage.','magup'); ?></span>
	<?php 
}
// Featured Articles Number
function magup_setting_feat_posts() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<input id='magup_setting_feat_posts' name='theme_magup_options[feat_posts]' size='40' type='text' value='<?php echo "{$magup_options['feat_posts']}" ?>' />
	<span class="description"><?php _e('Decide how many featured Articles with Thumbnails you would like do display. Leave empty to show all.','magup'); ?></span>
	<?php 
}
// Featured Categories Category ID
function magup_setting_feat_cats() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<input id='magup_setting_feat_cats' name='theme_magup_options[feat_cats]' size='40' type='text' value='<?php echo "{$magup_options['feat_cats']}" ?>' />
	<span class="description"><?php _e('This sets the category ID for featured Categories on Homepage.','magup'); ?></span>
	<?php 
}
// Sidebar 1 160x600px
function magup_setting_sidebar_banner_1() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<textarea style="width: 310px; height:70px; font-size: 10px; border: 1px solid #b6b6b6;" id='magup_setting_sidebar_banner_1' name='theme_magup_options[sidebar_banner_1]' size='40'><?php echo "{$magup_options['sidebar_banner_1']}" ?></textarea>
	<span class="description" style="vertical-align: top;"><?php _e('E.g. <span style="font-size: 9px; font-style: italic;">&lt;a href="http://wpwebhost.com/affiliate/idevaffiliate.php?id=1073_0_1_32" target="_blank"&gt; &lt;img border="0" src="http://wpwebhost.com/affiliate/banners/wp160x160.gif" width="160" height="160"&gt;&lt;/a&gt;</span>','magup'); ?></span>
	<?php 
}
// Sidebar 2 160x600px
function magup_setting_sidebar_banner_2() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<textarea style="width: 310px; height:70px; font-size: 10px; border: 1px solid #b6b6b6;" id='magup_setting_sidebar_banner_2' name='theme_magup_options[sidebar_banner_2]' size='40'><?php echo "{$magup_options['sidebar_banner_2']}" ?></textarea>
	<span class="description" style="vertical-align: top;"><?php _e('E.g. <span style="font-size: 9px; font-style: italic;">&lt;a href="http://wpwebhost.com/affiliate/idevaffiliate.php?id=1073_0_1_32" target="_blank"&gt; &lt;img border="0" src="http://wpwebhost.com/affiliate/banners/wp160x160.gif" width="160" height="160"&gt;&lt;/a&gt;</span>','magup'); ?></span>
	<?php 
}
// Content Banner 468x60px
function magup_setting_content_banner() {
     $magup_options = get_option( 'theme_magup_options' ); 
     ?>
	<textarea style="width: 310px; height:70px; font-size: 10px; border: 1px solid #b6b6b6;" id='magup_setting_content_banner' name='theme_magup_options[content_banner]' size='40'><?php echo "{$magup_options['content_banner']}" ?></textarea>
	<span class="description" style="vertical-align: top;"><?php _e('E.g. <span style="font-size: 9px; font-style: italic;">&lt;a href="http://wpwebhost.com/affiliate/idevaffiliate.php?id=1073_0_1_32" target="_blank"&gt; &lt;img border="0" src="http://wpwebhost.com/affiliate/banners/wp468x60.gif" width="468" height="60"&gt;&lt;/a&gt;</span>','magup'); ?></span>
	<?php
}
// validate our options
function magup_options_validate($input) {
	$options = get_option('theme_magup_options');
	$magup_options = magup_get_default_options();
	$options['slide_cat'] = trim($input['slide_cat']);
	if(!preg_match('/^[0-9,]*$/i', $options['slide_cat'])) {
		// reset to default if invalid
		$options['slide_cat'] = $magup_options['slide_cat'];
	}
	$options['slide_posts'] = trim($input['slide_posts']);
	if(!preg_match('/^[0-9]*$/i', $options['slide_posts'])) {
		// reset to default if invalid
		$options['slide_posts'] = $magup_options['slide_posts'];
	}
	$options['feat_cat'] = trim($input['feat_cat']);
	if(!preg_match('/^[0-9,]*$/i', $options['feat_cat'])) {
		// reset to default if invalid
		$options['feat_cat'] = $magup_options['feat_cat'];
	}
	$options['feat_posts'] = trim($input['feat_posts']);
	if(!preg_match('/^[0-9]*$/i', $options['feat_posts'])) {
		// reset to default if invalid
		$options['feat_posts'] = $magup_options['feat_posts'];
	}
	$options['feat_cats'] = trim($input['feat_cats']);
	if(!preg_match('/^[0-9,]*$/i', $options['feat_cats'])) {
		// reset to default if invalid
		$options['feat_cats'] = $magup_options['feat_cats'];
	}
	$options['sidebar_banner_1'] = trim($input['sidebar_banner_1']);
	$options['sidebar_banner_2'] = trim($input['sidebar_banner_2']);
	$options['content_banner'] = trim($input['content_banner']);
	
	return $options;
}



add_filter('next_posts_link_attributes', 'magup_get_next_posts_link_attributes');
add_filter('previous_posts_link_attributes', 'magup_get_previous_posts_link_attributes');

if (!function_exists('magup_get_next_posts_link_attributes')){
	function magup_get_next_posts_link_attributes($attr){
		$attr = 'title="'. __( 'Newer posts', 'magup' ).'"';
		return $attr;
	}
}
if (!function_exists('magup_get_previous_posts_link_attributes')){
	function magup_get_previous_posts_link_attributes($attr){
		$attr = 'title="'. __( 'Older posts', 'magup' ).'"';
		return $attr;
	}
}


/* wp_list_comments()->pings callback */
function magup_custom_pings($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment;
    if('pingback' == get_comment_type()) $pingtype = 'Pingback';
    else $pingtype = 'Trackback';
?>
    <li id="comment-<?php echo $comment->comment_ID ?>">
        <?php comment_author_link(); ?> - <?php echo $pingtype; ?> on <?php echo mysql2date('Y/m/d/ H:i', $comment->comment_date); ?>
<?php }